translate.storage.placeables.terminology.TerminologyPlaceable

Package translate :: Package storage :: Package placeables :: Module terminology :: Class TerminologyPlaceable |
[hide private]
[frames] | no frames]

# Class TerminologyPlaceable

source code

Terminology distinguished from the rest of a string by being a placeable.

Instance Methods | [hide private]
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
translate(self) Transform the sub-tree according to some class-specific needs. | source code
Inherited from `strelem.StringElem`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getitem__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__radd__`, `__repr__`, `__rmul__`, `__str__`, `__unicode__`, `apply_to_strings`, `copy`, `delete_elem`, `delete_range`, `depth_first`, `elem_at_offset`, `elem_offset`, `encode`, `find`, `find_elems_with`, `flatten`, `get_ancestor_where`, `get_index_data`, `get_parent_elem`, `insert`, `insert_between`, `isleaf`, `iter_depth_first`, `map`, `print_tree`, `prune`, `remove_type` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
parse(cls, pstr) hash(x) | source code

Class Variables | [hide private]
| matchers = ``[``]`` A list of matcher objects to use to identify terminology.
| translations = ``[``]`` The available translations for this placeable.
Inherited from `base.Ph`: `has_content`, `istranslatable` Inherited from `strelem.StringElem`: `iseditable`, `isfragile`, `isvisible`, `renderer`, `sub`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### parse(cls, pstr) Class Method | source code
hash(x) Parameters: `pstr` - The string to parse into an instance of this class. Returns: An instance of the current class, or `None` if the string not parseable by this class. Overrides: strelem.StringElem.parse (inherited documentation)

### translate(self) | source code
Transform the sub-tree according to some class-specific needs. This method should be either overridden in implementing sub-classes or dynamically replaced by specific applications. Returns: The transformed Unicode string representing the sub-tree. Overrides: strelem.StringElem.translate (inherited documentation)